@@ -27,8 +27,8 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include "app/logging.h"
 #include "createdialog.h"
+#include "ark_debug.h"
 #include "ui_createdialog.h"
 #include "kerfuffle/archive_kerfuffle.h"
 
@@ -61,7 +61,7 @@ CreateDialog::CreateDialog(QWidget *parent,
                            const QUrl &startDir)
         : QDialog(parent, Qt::Dialog)
 {
-    qCDebug(KERFUFFLE) << "CreateDialog loaded";
+    qCDebug(ARK) << "CreateDialog loaded";
 
     this->setWindowTitle(caption);
 
@@ -121,7 +121,7 @@ QString CreateDialog::password() const
 
 bool CreateDialog::isHeaderEncryptionChecked() const
 {
-    return m_ui->encryptHeaderCheckBox->isChecked();
+    return (m_ui->encryptHeaderCheckBox->isEnabled() && m_ui->encryptHeaderCheckBox->isChecked());
 }
 
 void CreateDialog::accept()
@@ -189,7 +189,7 @@ void CreateDialog::updateDefaultMimeType()
 
 void CreateDialog::updateDisplayedOptions(const QString &filter)
 {
-    qCDebug(KERFUFFLE) << "Current selected mime filter: " << filter;
+    qCDebug(ARK) << "Current selected mime filter: " << filter;
 
     if (Kerfuffle::supportedEncryptEntriesMimeTypes().contains(filter)) {
         m_ui->encryptCheckBox->setEnabled(true);
@@ -219,9 +219,9 @@ void CreateDialog::loadConfiguration()
 {
     m_config = KConfigGroup(KSharedConfig::openConfig()->group("AddDialog"));
 
-    const QString defaultMimeType = QLatin1String("application/x-compressed-tar");
+    const QString defaultMimeType = QStringLiteral("application/x-compressed-tar");
     const QString lastMimeType = m_config.readEntry("LastMimeType", defaultMimeType);
-    QStringList writeMimeTypes = Kerfuffle::supportedWriteMimeTypes();
+    QStringList writeMimeTypes = Kerfuffle::supportedWriteMimeTypes().toList();
 
     // The filters need to be sorted by comment, so create a QMap with
     // comment as key (QMaps are always sorted by key) and QMimeType
