@@ -25,8 +25,8 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include "app/logging.h"
 #include "extractiondialog.h"
+#include "ark_debug.h"
 #include "settings.h"
 
 #include <KLocalizedString>
@@ -57,7 +57,7 @@ ExtractionDialog::ExtractionDialog(QWidget *parent)
         : QDialog(parent, Qt::Dialog)
 
 {
-    qCDebug(KERFUFFLE) << "ExtractionDialog loaded";
+    qCDebug(ARK) << "ExtractionDialog loaded";
 
     setWindowTitle(i18nc("@title:window", "Extract"));
 
@@ -82,7 +82,7 @@ ExtractionDialog::ExtractionDialog(QWidget *parent)
     m_ui = new ExtractionDialogUI(this);
     hlayout->addWidget(m_ui);
 
-    m_ui->iconLabel->setPixmap(QIcon::fromTheme(QLatin1String("archive-extract")).pixmap(IconSize(KIconLoader::Desktop), IconSize(KIconLoader::Desktop)));
+    m_ui->iconLabel->setPixmap(QIcon::fromTheme(QStringLiteral("archive-extract")).pixmap(IconSize(KIconLoader::Desktop), IconSize(KIconLoader::Desktop)));
 
     m_ui->filesToExtractGroupBox->hide();
     m_ui->allFilesButton->setChecked(true);
