@@ -229,6 +229,8 @@ void Part::extractSelectedFilesTo(const QString& localPath)
     // Create and start the ExtractJob.
     ExtractJob *job = m_model->extractFiles(filesAndRootNodesForIndexes(addChildren(m_view->selectionModel()->selectedRows())), destination, options);
     registerJob(job);
+    connect(job, &KJob::result,
+            this, &Part::slotExtractionDone);
     job->start();
 }
 
@@ -503,9 +505,14 @@ bool Part::openFile()
     Q_ASSERT(archive->isValid());
 
     // Plugin loaded successfully.
-    KJob *job = m_model->setArchive(archive.take());
-    registerJob(job);
-    job->start();
+    KJob *job = m_model->setArchive(archive.take(), localFileInfo.exists());
+    if (job) {
+        registerJob(job);
+        job->start();
+    } else {
+        updateActions();
+    }
+
     m_infoPanel->setIndex(QModelIndex());
 
     if (arguments().metaData()[QStringLiteral("showExtractDialog")] == QLatin1String("true")) {
@@ -587,7 +594,7 @@ void Part::slotLoadingFinished(KJob *job)
 
     updateActions();
 
-    if (!m_model->archive()->comment().isEmpty()) {
+    if (m_model->archive() && !m_model->archive()->comment().isEmpty()) {
         m_commentView->setPlainText(m_model->archive()->comment());
         m_commentBox->show();
         m_commentSplitter->setSizes(QList<int>() << m_view->height() * 0.6 << 1);
